<?php

namespace Litecms\Institute\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Litecms\Institute\Http\Requests\InstituteCourseRequest;
use Litecms\Institute\Interfaces\InstituteCourseRepositoryInterface;
use Litecms\Institute\Models\InstituteCourse;

/**
 * Resource controller class for institute_course.
 */
class InstituteCourseResourceController extends BaseController
{

    /**
     * Initialize institute_course resource controller.
     *
     * @param type InstituteCourseRepositoryInterface $institute_course
     *
     * @return null
     */
    public function __construct(InstituteCourseRepositoryInterface $institute_course)
    {
        parent::__construct();
        $this->repository = $institute_course;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Litecms\Institute\Repositories\Criteria\InstituteCourseResourceCriteria::class);
    }

    /**
     * Display a list of institute_course.
     *
     * @return Response
     */
    public function index(InstituteCourseRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Litecms\Institute\Repositories\Presenter\InstituteCoursePresenter::class)
                ->$function();
        }

        $institute_courses = $this->repository->paginate();

        return $this->response->title(trans('institute::institute_course.names'))
            ->view('institute::institute_course.index', true)
            ->data(compact('institute_courses'))
            ->output();
    }

    /**
     * Display institute_course.
     *
     * @param Request $request
     * @param Model   $institute_course
     *
     * @return Response
     */
    public function show(InstituteCourseRequest $request, InstituteCourse $institute_course)
    {

        if ($institute_course->exists) {
            $view = 'institute::institute_course.show';
        } else {
            $view = 'institute::institute_course.new';
        }

        return $this->response->title(trans('app.view') . ' ' . trans('institute::institute_course.name'))
            ->data(compact('institute_course'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new institute_course.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(InstituteCourseRequest $request)
    {

        $institute_course = $this->repository->newInstance([]);
        return $this->response->title(trans('app.new') . ' ' . trans('institute::institute_course.name')) 
            ->view('institute::institute_course.create', true) 
            ->data(compact('institute_course'))
            ->output();
    }

    /**
     * Create new institute_course.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(InstituteCourseRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $institute_course                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('institute::institute_course.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('institute/institute_course/' . $institute_course->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/institute/institute_course'))
                ->redirect();
        }

    }

    /**
     * Show institute_course for editing.
     *
     * @param Request $request
     * @param Model   $institute_course
     *
     * @return Response
     */
    public function edit(InstituteCourseRequest $request, InstituteCourse $institute_course)
    {
        return $this->response->title(trans('app.edit') . ' ' . trans('institute::institute_course.name'))
            ->view('institute::institute_course.edit', true)
            ->data(compact('institute_course'))
            ->output();
    }

    /**
     * Update the institute_course.
     *
     * @param Request $request
     * @param Model   $institute_course
     *
     * @return Response
     */
    public function update(InstituteCourseRequest $request, InstituteCourse $institute_course)
    {
        try {
            $attributes = $request->all();

            $institute_course->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('institute::institute_course.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('institute/institute_course/' . $institute_course->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('institute/institute_course/' . $institute_course->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the institute_course.
     *
     * @param Model   $institute_course
     *
     * @return Response
     */
    public function destroy(InstituteCourseRequest $request, InstituteCourse $institute_course)
    {
        try {

            $institute_course->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('institute::institute_course.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('institute/institute_course/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('institute/institute_course/' . $institute_course->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple institute_course.
     *
     * @param Model   $institute_course
     *
     * @return Response
     */
    public function delete(InstituteCourseRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('institute::institute_course.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('institute/institute_course'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/institute/institute_course'))
                ->redirect();
        }

    }

    /**
     * Restore deleted institute_courses.
     *
     * @param Model   $institute_course
     *
     * @return Response
     */
    public function restore(InstituteCourseRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('institute::institute_course.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/institute/institute_course'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/institute/institute_course/'))
                ->redirect();
        }

    }

}
